@@ -1,9 +1,8 @@
 from django import forms
-from django.core.exceptions import ObjectDoesNotExist
 from django.test import TestCase, override_settings
 from edc_appointment.models import Appointment
 from edc_consent import site_consents
-from edc_constants.constants import COMPLETE, INCOMPLETE
+from edc_constants.constants import INCOMPLETE
 from edc_facility import import_holidays
 from edc_form_validators import FormValidator, FormValidatorMixin
 from edc_reference import site_reference_configs
@@ -12,11 +11,10 @@ from edc_visit_schedule import site_visit_schedules
 from edc_visit_tracking.constants import SCHEDULED
 from edc_visit_tracking.tests.helper import Helper
 from visit_schedule_app.consents import v1_consent
-from visit_schedule_app.models import SubjectConsent, SubjectVisit
+from visit_schedule_app.models import SubjectConsent, SubjectScreening, SubjectVisit
 
-from edc_crf.form_validator_mixins import CrfFormValidatorMixin
+from edc_crf.crf_form_validator_mixins import CrfFormValidatorMixin
 from edc_crf.modelform_mixins import CrfModelFormMixin
-from edc_crf.models import CrfStatus
 
 from ..models import Crf
 from ..visit_schedule import visit_schedule
@@ -35,6 +33,11 @@ class EdcCrfTestCase(TestCase):
         return super().setUpClass()
 
     def setUp(self):
+        SubjectScreening.objects.create(
+            screening_identifier="ABCD",
+            screening_datetime=get_utcnow(),
+            subject_identifier="12345",
+        )
         self.subject_identifier = "12345"
         site_consents.registry = {}
         site_consents.register(v1_consent)
@@ -54,37 +57,6 @@ class EdcCrfTestCase(TestCase):
             appointment=appointment, report_datetime=get_utcnow(), reason=SCHEDULED
         )
 
-    def test_default_incomplete(self):
-        crf_obj = Crf.objects.create(subject_visit=self.subject_visit)
-        self.assertEqual(crf_obj.crf_status, INCOMPLETE)
-
-    @override_settings(CRF_STATUS_DEFAULT=COMPLETE)
-    def test_default_complete(self):
-        crf_obj = Crf.objects.create(subject_visit=self.subject_visit)
-        self.assertEqual(crf_obj.crf_status, COMPLETE)
-
-    def test_creates_crf_status(self):
-        crf_obj = Crf.objects.create(subject_visit=self.subject_visit)
-        try:
-            CrfStatus.objects.get(
-                subject_identifier=crf_obj.subject_visit.subject_identifier,
-                label_lower="edc_crf.crf",
-            )
-        except ObjectDoesNotExist:
-            self.fail("crf status unexpectedly does not exist")
-
-    def test_deletes_crf_status(self):
-        crf_obj = Crf.objects.create(subject_visit=self.subject_visit)
-        self.assertEqual(crf_obj.crf_status, INCOMPLETE)
-        crf_obj.crf_status = COMPLETE
-        crf_obj.save()
-        self.assertRaises(
-            ObjectDoesNotExist,
-            CrfStatus.objects.get,
-            subject_identifier=crf_obj.subject_visit.subject_identifier,
-            label_lower="edc_crf.crf",
-        )
-
     def test_form_validator_with_crf(self):
         class MyFormValidator(CrfFormValidatorMixin, FormValidator):
             def clean(self) -> None:
@@ -93,9 +65,10 @@ class EdcCrfTestCase(TestCase):
                 _ = self.subject_consent
                 _ = self.subject_identifier
                 _ = self.report_datetime
+                _ = self.age_in_years
+                _ = self.offschedule_datetime
 
         class MyForm(CrfModelFormMixin, FormValidatorMixin, forms.ModelForm):
-
             form_validator_cls = MyFormValidator
 
             def validate_against_consent(self):
@@ -105,7 +78,40 @@ class EdcCrfTestCase(TestCase):
                 model = Crf
                 fields = "__all__"
 
-        # crf_obj = Crf.objects.create(subject_visit=self.subject_visit)
+        data = dict(
+            report_datetime=self.subject_visit.report_datetime,
+            subject_visit=self.subject_visit,
+            crf_status=INCOMPLETE,
+        )
+        form = MyForm(data=data)
+        form.is_valid()
+        self.assertEqual({}, form._errors)
+
+        # missing report_datetime
+        data = dict(
+            report_datetime=None,
+            subject_visit=self.subject_visit,
+            crf_status=INCOMPLETE,
+        )
+        form = MyForm(data=data)
+        form.is_valid()
+        self.assertIn("report_datetime", form._errors)
+
+        # gets report_datetime from instance
+        data = dict(
+            subject_visit=self.subject_visit,
+            crf_status=INCOMPLETE,
+        )
+        form = MyForm(data=data)
+        form.is_valid()
+        self.assertIn("report_datetime", form._errors)
+
+        # missing related_visit.subject_identifier not possible
+        # always returns subject_identifier
+        self.subject_visit.subject_identifier = None
+        self.subject_visit.save()
+        self.subject_visit.refresh_from_db()
+        self.assertIsNotNone(self.subject_visit.subject_identifier)
         data = dict(
             report_datetime=self.subject_visit.report_datetime,
             subject_visit=self.subject_visit,
